@@ -542,8 +542,10 @@ SELECT to_number(1210::bigint, 9999::bigint);
 SELECT to_number(1210.73::numeric, 9999.99::numeric);
 
 SELECT to_date('2009-01-02');
+SELECT to_date('', 'yyyy-mm-dd');
 SELECT to_date('112012', 'J');
 SELECT to_date('1003/03/15', 'yyyy/mm/dd');
+SELECT oracle.to_date('', 'yyyy-mm-dd');
 SELECT oracle.to_date('112012', 'J');
 SELECT oracle.to_date('1003-03-15', 'yyyy-mm-dd');
 SET orafce.oracle_compatibility_date_limit TO off;
